==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPCapability.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

#include "TRIPCapability.hxx"
#include "TRIPUtil.hxx"
#include "cpLog.h"

TRIPCapability::TRIPCapability(u_int16_t code)
{
    assert((code > 0) && (code < TRIP_CAP_MAX));
    _code = code;
    _length = 0;
}

TRIPCapability::TRIPCapability(const char* buf) throw(TRIPBadDataException&)
{
    u_int16_t code;
    u_int16_t  len;
    memcpy(&code, buf, 2);
    memcpy(&len, buf+2, 2);
    _code = ntohs(code); 
    _length = ntohs(len); 
    if((_code <= 0) || (_code >= TRIP_CAP_MAX))
    {
        cpLog(LOG_ALERT, "Bad TRIP Data");
        throw TRIPBadDataException("Bad TRIP Data", __FILE__, __LINE__, 0);
    }
}

void
TRIPCapability::copyObj(const TRIPCapability& other)
{
    _code = other._code;
    _length = other._length;
}

void 
TRIPCapability::writeData(int id) const throw(VNetworkException&)
{
    u_int16_t code;
    u_int16_t  len;

    code = htons(_code);
    len = htons(_length);
    TRIPUtil::writeData(id, &code, 2);
    TRIPUtil::writeData(id, &len, 2);
}

u_int16_t 
TRIPCapability::getLength() const
{
    ///Data length + 4 bytes holding the code and length
    return(_length+4);
}

void 
TRIPCapability::validate() const throw (TRIPBadDataException&)
{
    int code = _code; 
    if(( code < 0) || ( code >= TRIP_CAP_MAX))
    {
        throw TRIPBadDataException("Invalid Capability",
                                   __FILE__, __LINE__, 0);
    }
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPCapability.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
#include <netinet/in.h>

#include "TRIPCapability.hxx"
#include "TRIPUtil.hxx"
#include "TRIPErrorHandler.hxx"
#include "cpLog.h"

int TRIPCapability::_minLength = 4;

TRIPCapability::TRIPCapability(u_int16_t code)
{
    assert((code > 0) && (code < TRIP_CAP_MAX));
    _code = code;
    _length = 0;
}

TRIPCapability::TRIPCapability(const char* buf) throw(TRIPBadDataException&)
{
    u_int16_t code;
    u_int16_t  len;
    memcpy(&code, buf, 2);
    memcpy(&len, buf+2, 2);
    _code = ntohs(code); 
    _length = ntohs(len); 
    validate();
}

void
TRIPCapability::copyObj(const TRIPCapability& other)
{
    _code = other._code;
    _length = other._length;
}

void 
TRIPCapability::writeData(int id) const throw(VNetworkException&)
{
    u_int16_t code;
    u_int16_t  len;

    code = htons(_code);
    len = htons(_length);
    TRIPUtil::writeData(id, &code, 2);
    TRIPUtil::writeData(id, &len, 2);
}

u_int16_t 
TRIPCapability::getLength() const
{
    ///Data length + 4 bytes holding the code and length
    return(_length+_minLength);
}

void 
TRIPCapability::validate() const throw (TRIPBadDataException&)
{
    int code = _code; 
    if(( code <= 0) || ( code >= TRIP_CAP_MAX))
    {
        throw TRIPBadDataException("Invalid Capability",
                    __FILE__, __LINE__, TRIP_ERR_OPEN, O_UNSUPP_CAPABILITY);
    }
}
